<?php
/**
 * @package Manifest_Builder
 */
/*
 Plugin Name: Manifest_Builder
 Plugin URI: http://christian-illies.info/2012/06/wordpress-cache-manifest-plugin/
 Description: Adds a HTML 5 Application Cache (Cache-Manifest) to your Blog for all posts and categories. In addition you can add custom filepathes for caching specific layout images for example. A refresh will automatically be called if any blog post has changed, saved, deleted or created.
 Version: 0.5
 Author: Christian Illies
 Author URI: http://christian-illies.info
 */
require 'builder.php'; 

if (!class_exists('Manifest_Builder_Plugin')) 
{
	class Manifest_Builder_Plugin 
	{
		/**
		 * @var Manifest_Builder
		 */
		protected $builder;
		
		function __construct()
		{
			register_activation_hook(__FILE__, array(&$this,'activatePlugin'));
			register_deactivation_hook(__FILE__, array(&$this,'deactivatePlugin'));
		}
		
		public function activatePlugin()
		{
			add_option('manifest_custom_files');
			add_option('manifest_fallback_files');
			
			add_action('publish_post', array(&$this,'manifestinate'));
			add_action('trash_post', array(&$this,'manifestinate'));
			add_action('delete_post', array(&$this,'manifestinate'));
			add_action('edit_post', array(&$this,'manifestinate'));
			add_action('save_post', array(&$this,'manifestinate'));
			add_action('xmlrpc_publish_post', array(&$this,'manifestinate'));
			add_action('comment_post', array(&$this,'manifestinate'));
			add_action('pingback_post', array(&$this,'manifestinate'));
			add_action('trackback_post', array(&$this,'manifestinate'));
		}
		
		public function deactivatePlugin()
		{
			delete_option('manifest_custom_files');
			delete_option('manifest_fallback_files');
			
			remove_action('publish_post', array(&$this,'manifestinate'));
			remove_action('trash_post', array(&$this,'manifestinate'));
			remove_action('delete_post', array(&$this,'manifestinate'));
			remove_action('edit_post', array(&$this,'manifestinate'));
			remove_action('save_post', array(&$this,'manifestinate'));
			remove_action('xmlrpc_publish_post', array(&$this,'manifestinate'));
			remove_action('comment_post', array(&$this,'manifestinate'));
			remove_action('pingback_post', array(&$this,'manifestinate'));
			remove_action('trackback_post', array(&$this,'manifestinate'));
		}
		
		function manifestinate() 
		{
			$this->builder = new Manifest_Builder;
			$this->builder->setManifestPath(realpath(dirname(__FILE__) . '/../../../cache.manifest'));
		
			$posts_array = array_merge(get_posts(array('numberposts' => 25, 'post_status' => 'publish')), get_posts(array('numberposts' => 25, 'post_status' => 'publish', 'post_type' => 'page')));
			$categories_array = get_all_category_ids();
			
			$this->builder->addCacheFiles(explode("\n", get_option('manifest_custom_files')));
			foreach ($posts_array as $post_object) {
				$this->builder->addCacheFile(get_permalink($post_object->ID));
			}
			foreach ($categories_array as $category_id) {
				$this->builder->addCacheFile(get_category_link($category_id));
			}
			$this->builder->addNetworkFile('*');
			foreach (explode("\n", get_option('manifest_fallback_files')) as $fallback) {
				$fallback_array = explode(' ',$fallback);
				$dynamic_file = $fallback_array[0];
				$fallback_path = $fallback_array[1];
				$this->builder->addFallback($dynamic_file, $fallback_path);
			}
			//$this->builder->addFallbacks(explode("\n", get_option('manifest_fallback_files')));
			
			$this->builder->refresh();
		}
	}
	
	$manifest_plugin = new Manifest_Builder_Plugin;
}

if( isset( $manifest_plugin ) ) {
   add_action( 'init', array( &$manifest_plugin, 'activatePlugin' ) );
}

include 'template_functions.php';
include 'admin_menu.php';